@@ -141,22 +141,30 @@ GSM_Error GSM_StateMachine::Open(GSM_GPlusConfig *CFG)
         return GSM_Return_Error(GSM_ERR_NONE);
 }
 
+BOOLEAN GSM_StateMachine::ReadCfgFile(INI_File *File)
+{
+#ifndef WIN32
+	char		tmp[500];
+#endif
+	BOOLEAN		read = FALSE;
+
+	if (read==FALSE && File->ReadFile("gammurc")==TRUE) read = TRUE;
+#ifndef WIN32
+	strcpy(tmp,getenv("HOME"));
+	strcat(tmp,"/.gammurc");
+	if (read==FALSE && File->ReadFile(tmp)==TRUE) read = TRUE;
+	if (read==FALSE && File->ReadFile("/etc/gammurc")==TRUE) read = TRUE;
+#endif
+	return read;
+}
+
 void GSM_StateMachine::ReadCfg(GSM_GPlusConfig *CFG)
 {
 	INI_File	File;
 	wchar_t		*value, x[200];
-	BOOLEAN		read = FALSE;
-#ifndef WIN32
-	char		tmp[500];
-#endif
+	BOOLEAN		read;
 
-	if (read==FALSE && File.ReadFile("gammurc")==TRUE) read = TRUE;
-#ifndef WIN32
-	strcpy(tmp,getenv("HOME"));
-	strcat(tmp,"/.gammurc");
-	if (read==FALSE && File.ReadFile(tmp)==TRUE) read = TRUE;
-	if (read==FALSE && File.ReadFile("/etc/gammurc")==TRUE) read = TRUE;
-#endif
+	read = ReadCfgFile(&File);
 
 	StringToUnicode("gammu",x);
 
@@ -182,6 +190,18 @@ void GSM_StateMachine::ReadCfg(GSM_GPlusConfig *CFG)
 	CFG->RSSLevel[0] = 0;
 	value = File.GetValue(x,StringToUnicodeReturn("rsslevel"));
 	if (value != NULL) sprintf(CFG->RSSLevel,"%s",UnicodeToStringReturn(value));
+
+	strcpy(CFG->LogLevel,"nothing");
+	value = File.GetValue(x,StringToUnicodeReturn("logformat"));
+	if (value != NULL) sprintf(CFG->LogLevel,"%s",UnicodeToStringReturn(value));
+
+	strcpy(CFG->LogFile,"");
+	value = File.GetValue(x,StringToUnicodeReturn("logfile"));
+	if (value != NULL) sprintf(CFG->LogFile,"%s",UnicodeToStringReturn(value));
+
+	strcpy(CFG->SyncTime,"no");
+	value = File.GetValue(x,StringToUnicodeReturn("synchronizetime"));
+	if (value != NULL) sprintf(CFG->SyncTime,"%s",UnicodeToStringReturn(value));
 }
 
 /**
@@ -191,18 +211,9 @@ void GSM_StateMachine::SaveCfg(GSM_GPlusConfig *CFG)
 {
 	INI_File	File;
 	wchar_t		x[200], x2[200];
-	BOOLEAN		read = FALSE;
-#ifndef WIN32
-	char		tmp[500];
-#endif
+	BOOLEAN		read;
 
-	if (read==FALSE && File.ReadFile("gammurc")==TRUE) read = TRUE;
-#ifndef WIN32
-	strcpy(tmp,getenv("HOME"));
-	strcat(tmp,"/.gammurc");
-	if (read==FALSE && File.ReadFile(tmp)==TRUE) read = TRUE;
-	if (read==FALSE && File.ReadFile("/etc/gammurc")==TRUE) read = TRUE;
-#endif
+	read = ReadCfgFile(&File);
 
 	StringToUnicode("gammu",x);
 
@@ -218,6 +229,15 @@ void GSM_StateMachine::SaveCfg(GSM_GPlusConfig *CFG)
 	StringToUnicode("compatibility",x2);
 	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Compatibility));
 
+	StringToUnicode("logformat",x2);
+	File.SetValue(x,x2,StringToUnicodeReturn(CFG->LogLevel));
+
+	StringToUnicode("logfile",x2);
+	File.SetValue(x,x2,StringToUnicodeReturn(CFG->LogFile));
+
+	StringToUnicode("synchronizetime",x2);
+	File.SetValue(x,x2,StringToUnicodeReturn(CFG->SyncTime));
+
 	if (read) {
 		File.SaveToDisk(UnicodeToStringReturn(File.Info.ID.data()));
 	} else {
