@@ -14,6 +14,9 @@ typedef struct {
 	char		Protocol[200];
 	char		Phone[200];
 	char		Compatibility[200];
+	char		LogFile[500];
+	char		LogLevel[200];
+	char		SyncTime[200];
 
 	char		RSSLevel[200];
 } GSM_GPlusConfig;
@@ -40,6 +43,8 @@ public:
 	GSM_Error		Close		();
 	void 			SetUserReply	(GSM_Error(*UsrReply)(int MsgLength, unsigned char MsgType, unsigned char *MsgBuffer, void *Struct, int RequestID));
 	void 			SetSMSSendReply	(void(*SMSSndReply)(int TPMR));
+private:
+	BOOLEAN 		ReadCfgFile	(INI_File *File);
 };
 
 #endif
