@@ -425,7 +425,7 @@ GSM_Error GSM_Phone::ReadFolderToCache(wchar_t *ID, GSM_FileFolderInfoList **Lis
 
 	En = NULL;
 	while (FoldersCache.GetNext(&En)) {
-		if (!wcscmp(En->Info.Info.GetID(),ID)) {
+		if (!wcscmp(En->Info.Info.ID.data(),ID)) {
 			*List = &En->Info;
 			return GSM_Return_Error(GSM_ERR_NONE);
 		}
@@ -570,6 +570,11 @@ GSM_Error GSM_Phone::GetFirmwareDate(unsigned char *Date)
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
+GSM_Error GSM_Phone::GetProductCode(unsigned char *ProductCode)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
 GSM_Error GSM_Phone::GetPBKStatus(GSM_PBKStatus *Status)
 {
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
@@ -605,6 +610,36 @@ GSM_Error GSM_Phone::DeleteCalendar(GSM_CalendarEntry *Entry)
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
+GSM_Error GSM_Phone::GetNextNote(GSM_NoteEntry *Entry, BOOLEAN start, int *Current, int *Max)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
+GSM_Error GSM_Phone::AddNote(GSM_NoteEntry *Entry)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
+GSM_Error GSM_Phone::DeleteNote(GSM_NoteEntry *Entry)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
+GSM_Error GSM_Phone::GetNextToDo(GSM_ToDoEntry *Entry, BOOLEAN start, int *Current, int *Max)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
+GSM_Error GSM_Phone::AddToDo(GSM_ToDoEntry *Entry)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
+GSM_Error GSM_Phone::DeleteToDo(GSM_ToDoEntry *Entry)
+{
+	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+}
+
 GSM_Error GSM_Phone::GetDateTime(GSM_DateTime *DT)
 {
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
@@ -662,7 +697,7 @@ GSM_Error GSM_Phone::SetSMSC(GSM_SMSC *SMSC)
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
-GSM_Error GSM_Phone::GetFileFolderInfo(GSM_FileFolderInfo *FInfo)
+GSM_Error GSM_Phone::GetFileFolderInfo(FileFolderInfo *FInfo)
 {
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
@@ -712,7 +747,7 @@ GSM_Error GSM_Phone::DeleteFolder(wchar_t *FolderID)
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
-GSM_Error GSM_Phone::AddFolder(GSM_FileFolderInfo *FInfo)
+GSM_Error GSM_Phone::AddFolder(FileFolderInfo *FInfo)
 {
 	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
