@@ -41,7 +41,49 @@ GSM_Error GSM_Phone_N6510::GetNextNote(GSM_NoteEntry *Entry, BOOLEAN start, int
 
 GSM_Error GSM_Phone_N6510::AddNote(GSM_NoteEntry *Entry)
 {
-	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	int		     	Loc;
+	unsignedstring	  	Buffer,Buffer2;
+	GSM_Error	       	error;
+	unsigned char	   	req[54] = {
+		NOKIA_FRAME1, 0x65,
+		0x02,				   	/* 0 = calendar, 1 = todo	       */
+		0x00, 0x00, 0x00,
+		0x00, 0x00,			     	/* location			     */
+		0x00, 0x00, 0x00, 0x00,
+		0xFF, 0xFF, 0xFF, 0xFF,		 	/* alarm				*/
+		0x80, 0x00, 0x00,
+		0x01,				   	/* note icon			    */
+		0xFF, 0xFF, 0xFF, 0xFF,		 	/* alarm type			   */
+		0x00,				   	/* 0x02 or 0x00			 */
+		0x01,				   	/* note type			    */
+		0x07, 0xD0, 0x01, 0x12, 0x0C, 0x00,     /* start date/time		      */
+		0x07, 0xD0, 0x01, 0x12, 0x0C, 0x00,     /* end date/time			*/
+		0x00, 0x00,			     	/* recurrance			   */
+		0x00, 0x00,			     	/* birth year			   */
+		0x20,				   	/* ToDo priority			*/
+		0x00,				   	/* ToDo completed ?		     */
+		0x00, 0x00,			     	/* How many times repeat cal note or 0  */
+		0x00,
+		0x00,				   	/* note text length		     */
+		0x00,				   	/* phone length/meeting place	   */
+		0x00, 0x00, 0x00};
+	
+	error=GetFirstCalendarPos3(&Loc);
+	if (error.Code!=GSM_ERR_NONE) return error;
+	req[8] = Loc/256;
+	req[9] = Loc%256;
+
+	req[49] = UnicodeLength(Entry->Text.data());
+	NokiaSetUnicodeString(Entry->Text.data(),&Buffer);
+
+	Buffer.push_back(0x00);
+
+	Buffer2.append((const unsigned char*)req,sizeof(req));
+	Buffer2.append((const unsigned char*)Buffer.data(),Buffer.size());
+
+	(*Debug)->Deb("SENT: Adding note\n");
+	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x13, 4, ID_AddNote+ID,Entry);
+//	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
 GSM_Error GSM_Phone_N6510::DeleteNote(GSM_NoteEntry *Entry)
@@ -58,7 +100,10 @@ GSM_Error GSM_Phone_N6510::GetNextToDo(GSM_ToDoEntry *Entry, BOOLEAN start, int
 
 GSM_Error GSM_Phone_N6510::AddToDo(GSM_ToDoEntry *Entry)
 {
-	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	if (!(*Phones)->Feature("todo6610")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+
+	return AddToDo2(Entry);
+//	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
 GSM_Error GSM_Phone_N6510::DeleteToDo(GSM_ToDoEntry *Entry)
@@ -694,3 +739,8 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 	(*Debug)->Deb("SENT: Adding calendar note (method 3)\n");
 	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x13, 4, ID_AddCalendar+ID,Entry);
 }
+
+GSM_Error GSM_Phone_N6510::AddToDo2(GSM_ToDoEntry *Entry)
+{
+	return GSM_Return_Error(GSM_ERR_UNKNOWN);
+}
