@@ -25,6 +25,7 @@ if(Ans("\x03",0x03,0x04,ID_GetPBKStatus+ID,&AS))     	return ReplyGetPBKStatus
 if(Ans("\x03",0x03,0x08,ID_GetPBK+ID, &AS))     	return ReplyGetPBK 			(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x03",0x03,0x0C,ID_SetPBK+ID, &AS))     	return DCT34->ReplySetPBK 		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x03",0x03,0x10,ID_DelPBK+ID, &AS))     	return DCT34->ReplyDelPBK 		(msg,Debug,(unsigned char *)Struct);
+if(Ans("\x03",0x03,0x26,ID_GetPBK+ID3, &AS))     	return DCT34->ReplyGetPBKFeatures 	(msg,Debug,(unsigned char *)Struct);
 
 if(Ans("\x13",0x03,0x02,ID_AddCalendar+ID3,&AS))   	return DCT34->ReplyAddCalendar1		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x04,ID_AddCalendar+ID3,&AS))   	return DCT34->ReplyAddCalendar1		(msg,Debug,(unsigned char *)Struct);
@@ -239,13 +240,19 @@ GSM_Error GSM_Phone_N6510::SetPBK(GSM_PBKEntry *Entry)
 {
 	unsignedstring 		Buffer, Buffer2;
 	GSM_Error		error;
-	int			Number;
+	int			Number = 0;
 	unsigned char		Buff[] = {
 		NOKIA_FRAME1, 0x0b, 0x00, 0x01, 0x01, 0x00, 0x00, 0x10, 0x02, 
 		0x00,  			// memory type
 		0x00, 0x00,  		// location
 		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
 
+	if (Entry->Memory == MEM_PHONE && PhonePBKFeatures.Types.size() == 0) {
+		PhonePBKFeatures.Memory = MEM_PHONE;
+		error = DCT34->GetPBKFeatures(&PhonePBKFeatures);
+		if (error.Code != GSM_ERR_NONE) return error;
+	}
+
 	Buff[11] = DCT34->Get7110DCT4MemoryType(Entry->Memory);
 	if (Buff[11] == 0x00) return GSM_Return_Error(GSM_ERR_UNKNOWN);
 
@@ -253,15 +260,28 @@ GSM_Error GSM_Phone_N6510::SetPBK(GSM_PBKEntry *Entry)
 	Buff[12] = Entry->Location / 256;
 	Buff[13] = Entry->Location % 256;
 
-	error = DCT34->EncodeEntryToPBK(&Buffer, Entry, &Number);
-	if (error.Code != GSM_ERR_NONE) return error;
+	while (true) {
+		if (Entry->Memory == MEM_PHONE) {
+			error = DCT34->EncodeEntryToPBK(&Buffer, Entry, &Number, &PhonePBKFeatures);
+		} else {
+			error = DCT34->EncodeEntryToPBK(&Buffer, Entry, &Number, NULL);
+		}
+		if (error.Code != GSM_ERR_NONE) return error;
 
-	Buffer2.append((const unsigned char*)Buff,sizeof(Buff));
-	Buffer2.push_back(Number);
-	Buffer2.append((const unsigned char*)Buffer.data(),Buffer.size());
+		Buffer2.append((const unsigned char*)Buff,sizeof(Buff));
+		Buffer2.push_back(Number);
+		Buffer2.append((const unsigned char*)Buffer.data(),Buffer.size());
 
-	(*Debug)->Deb("SENT: setting entry %i in memory %s\n",Entry->Location,GSM_GetMemoryName(Entry->Memory));
-	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x03, 4, ID_SetPBK+ID, Entry);
+		(*Debug)->Deb("SENT: setting entry %i in memory %s\n",Entry->Location,GSM_GetMemoryName(Entry->Memory));
+		error = Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x03, 4, ID_SetPBK+ID, Entry);
+		if (error.Code == GSM_ERR_TOO_MANY_ENTRIES) {
+			Buffer.clear();
+			Buffer2.clear();
+			Number--;
+			continue;
+		}
+		return error;
+	}
 }
 
 GSM_Error GSM_Phone_N6510::DeletePBK(GSM_PBKEntry *Entry)
