@@ -137,6 +137,9 @@ public:
         GSM_Error        GetJavaAppsFolderID    (wchart *ID, BOOLEAN *NeedSubFolder, BOOLEAN Start);
 private:
         GSM_Phone_NDCT34                *DCT34;
+	//pbk
+	GSM_PBK_Features		PhonePBKFeatures;
+	GSM_PBK_Features		SIMPBKFeatures;
         //calendar
         int                             CurrentCalendarNumber;
         GSM_Cal_Loc                     CalendarLocations;
@@ -165,6 +168,7 @@ private:
 	GSM_Error 	 PrivGetCalendar3NoteToDo2(void *Entry, int Location, int request);
 	GSM_Error 	 GetCalendar3NoteToDo2Info(unsigned char type);
         GSM_Error        AddCalendar3           (GSM_CalendarEntry *Entry);
+	GSM_Error 	 AddToDo2		(GSM_ToDoEntry *Entry);
         GSM_Error        GetFirstCalendarPos3   (int *Location);
 	GSM_Error 	 FindCalendarNoteType3	(GSM_CalendarEntry *Entry, int *NoteID);
         //sms
