@@ -156,13 +156,102 @@ void GSM_Phone_NDCT34::SetFrameID(char *Id)
 	memcpy(FrameID,(const char *)Id,strlen((const char *)Id)+1);
 }
 
-GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntry *Entry, int *Number)
+GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntry *Entry, int *Number, GSM_PBK_Features *Features)
 {
 	GSM_PBKSubEntry	 *SubEntry;
-	int		     Type, Type2;
-	unsignedstring	  TempBuffer;
+	unsigned int	i;
+	int		 Type, Type2, MaxNum;
+	int		 Name=1;//1-old name,2-last/first
+	unsignedstring	 TempBuffer, TempBuffer2;
+	BOOLEAN		 Avail;
+	wchart		 Buff;
 
+	SubEntry  = NULL;
+	while (Entry->GetNext(&SubEntry)) {
+		SubEntry->SetError = GSM_Return_Error(GSM_ERR_TOO_MANY_ENTRIES);
+	}
+	MaxNum = (*Number);
 	(*Number) = 0;
+
+	if (Features != NULL) {
+		for (i=0;i<Features->Types.size();i++) {
+			if (Features->Types.data()[i] == NPBK_NAME_LAST) {
+				Name=2;
+				break;
+			}
+		}
+	}
+	SubEntry  = NULL;
+	while (Entry->GetNext(&SubEntry)) {
+		if (SubEntry->GetType()==PBK_Text_Name_Last) {
+			Buff.append(SubEntry->GetText(),UnicodeLength(SubEntry->GetText()));
+		}	
+	}
+	SubEntry  = NULL;
+	while (Entry->GetNext(&SubEntry)) {
+		if (SubEntry->GetType()==PBK_Text_Name_First) {
+			Buff.push_back(' ');
+			Buff.append(SubEntry->GetText(),UnicodeLength(SubEntry->GetText()));
+		}
+	}
+	if (Name==1) {
+		if (Buff.size()!=0) {
+			SubEntry  = NULL;
+			while (Entry->GetNext(&SubEntry)) {
+				if (SubEntry->GetType()==PBK_Text_Name_First) {
+					SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+				}
+				if (SubEntry->GetType()==PBK_Text_Name_Last) {
+					SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+				}
+			}
+
+			if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+
+			TempBuffer.clear();
+			TempBuffer.push_back(((Buff.length()+1)*2)%256);
+			NokiaSetUnicodeString(Buff.data(),&TempBuffer);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+
+			Buffer->push_back(NPBK_NAME);
+			Buffer->push_back(0x00);
+			Buffer->push_back((TempBuffer.size()+6) / 256);
+			Buffer->push_back((TempBuffer.size()+6) % 256);
+			Buffer->push_back(++(*Number));
+			Buffer->append((const unsigned char*)TempBuffer.data(),TempBuffer.size());
+			Buffer->push_back(0x00);
+			Name=0;
+		}
+	} else if (Name==2) {
+		if (Buff.size()==0) {
+			SubEntry = NULL;
+			while (Entry->GetNext(&SubEntry)) {
+				if (SubEntry->GetType()!=PBK_Text_Name) continue;
+
+				if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+
+				TempBuffer.clear();
+				TempBuffer.push_back(((UnicodeLength(SubEntry->GetText())+1)*2)%256);
+				NokiaSetUnicodeString(SubEntry->GetText(),&TempBuffer);
+				TempBuffer.push_back(0x00);
+				TempBuffer.push_back(0x00);
+				TempBuffer.push_back(0x00);
+
+				SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+				Buffer->push_back(NPBK_NAME_LAST);
+				Buffer->push_back(0x00);
+				Buffer->push_back((TempBuffer.size()+6) / 256);
+				Buffer->push_back((TempBuffer.size()+6) % 256);
+				Buffer->push_back(++(*Number));
+				Buffer->append((const unsigned char*)TempBuffer.data(),TempBuffer.size());
+				Buffer->push_back(0x00);
+			}
+			Name=0;
+		}
+	}
+
 	SubEntry  = NULL;
 	while (Entry->GetNext(&SubEntry)) {
 		TempBuffer.clear();
@@ -190,20 +279,38 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			TempBuffer.push_back(0x00);
 			TempBuffer.push_back(0x00);
 			break;		  
-		case PBK_Text_Note:
-			Type = NPBK_NOTE; //no break
 		case PBK_Text_Postal:
-			if (Type == 0x00) Type = NPBK_POSTAL; //no break
+		case PBK_Text_Postal_Street:
+		case PBK_Text_Postal_City:
+		case PBK_Text_Postal_State:
+		case PBK_Text_Postal_ZIP_Code:
+		case PBK_Text_Postal_Country:
+			break;
 		case PBK_Text_Email:
 			if (Type == 0x00) Type = NPBK_EMAIL; //no break
-		case PBK_Text_Name:
-			if (Type == 0x00) Type = NPBK_NAME; //no break
-		case PBK_Text_Name_First:
-			if (Type == 0x00) Type = NPBK_NAME_FIRST; //no break
-		case PBK_Text_Name_Last:
-			if (Type == 0x00) Type = NPBK_NAME_LAST; //no break
 		case PBK_Text_URL:
-			if (Type == 0x00) Type = NPBK_URL;
+			if (Type == 0x00) Type = NPBK_URL; //no break
+		case PBK_Text_UserID:
+			if (Type == 0x00) Type = NPBK_USER_ID; //no break
+		case PBK_Text_Note:
+			if (Type == 0x00) Type = NPBK_NOTE; //no break
+		case PBK_Text_Name:
+			if (Type == 0x00) {
+				Type = NPBK_NAME; //no break
+				if (Name!=1) break;
+			}
+		case PBK_Text_Name_First:
+			if (Type == 0x00) {
+				Type = NPBK_NAME_FIRST; //no break
+				if (Name!=2) break;
+			}
+		case PBK_Text_Name_Last:
+			if (Type == 0x00) {
+				Type = NPBK_NAME_LAST; //no break
+				if (Name!=2) break;
+			}
+		case PBK_Text_PTT:
+			if (Type == 0x00) Type = NPBK_PUSHTOTALK_ID; //no break
 			Type2 = Type;
 			TempBuffer.push_back(((UnicodeLength(SubEntry->GetText())+1)*2)%256);
 			NokiaSetUnicodeString(SubEntry->GetText(),&TempBuffer);
@@ -211,13 +318,13 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			TempBuffer.push_back(0x00);
 			TempBuffer.push_back(0x00);
 			break;
-		case PBK_Text_UserID:
-			break;
 		default:
 			return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		}
 
 		if (TempBuffer.size() != 0) {
+			if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
 			Buffer->push_back(Type2);
 			Buffer->push_back(0x00);
 			Buffer->push_back((TempBuffer.size()+6) / 256);
@@ -228,12 +335,112 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 		}
 	}
 
+	//---------------------- address entries ------------------------------
+	Avail = TRUE;
+	if (Features != NULL) {
+		Avail = FALSE;
+		for (i=0;i<Features->Types.size();i++) {
+			if (Features->Types.data()[i] == NPBK_POSTAL2) {
+				Avail = TRUE;
+				break;
+			}
+		}
+	}
+//	Avail = FALSE;
+	i = 0;
+	SubEntry  = NULL;
+	while (Entry->GetNext(&SubEntry)) {
+		Type = 0x00;
+		TempBuffer.clear();
+		switch (SubEntry->GetType()) {
+		case PBK_Text_Postal:
+			Type = NPBK_POSTAL2_ADDRESS;
+			break;
+		case PBK_Text_Postal_Street:
+			Type = NPBK_POSTAL2_STREET;
+			break;
+		case PBK_Text_Postal_City:
+			Type = NPBK_POSTAL2_CITY;
+			break;
+		case PBK_Text_Postal_State:
+			Type = NPBK_POSTAL2_STATE;
+			break;
+		case PBK_Text_Postal_ZIP_Code:
+			Type = NPBK_POSTAL2_ZIPCODE;
+			break;
+		case PBK_Text_Postal_Country:
+			Type = NPBK_POSTAL2_COUNTRY;
+		default:
+			break;
+		}
+
+		if (Type == 0) continue;
+
+		if (Avail) {
+			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+			i++;
+
+			TempBuffer.push_back(0x07);
+			TempBuffer.push_back(((UnicodeLength(SubEntry->GetText())+1)*2)%256);
+			NokiaSetUnicodeString(SubEntry->GetText(),&TempBuffer);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+
+			TempBuffer2.push_back(Type);
+			TempBuffer2.push_back(0x00);
+			TempBuffer2.push_back((TempBuffer.size()+4) / 256);
+			TempBuffer2.push_back((TempBuffer.size()+4) % 256);
+			TempBuffer2.append((const unsigned char*)TempBuffer.data(),TempBuffer.size());
+		} else {
+			if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+
+			if (Type == NPBK_POSTAL2_ADDRESS) {
+				SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+				Type = NPBK_POSTAL;
+			} else {
+				SubEntry->SetError = GSM_Return_Error(GSM_ERR_CONVERTED);
+				Type = NPBK_NOTE;
+			}
+			TempBuffer.push_back(((UnicodeLength(SubEntry->GetText())+1)*2)%256);
+			NokiaSetUnicodeString(SubEntry->GetText(),&TempBuffer);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+
+			Buffer->push_back(Type);
+			Buffer->push_back(0x00);
+			Buffer->push_back((TempBuffer.size()+6) / 256);
+			Buffer->push_back((TempBuffer.size()+6) % 256);
+			Buffer->push_back(++(*Number));
+			Buffer->append((const unsigned char*)TempBuffer.data(),TempBuffer.size());
+			Buffer->push_back(0x00);
+		}
+
+	}
+	if (Avail && i!=0) {
+		if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+
+		TempBuffer.clear();
+		TempBuffer.push_back(0x00);
+		TempBuffer.push_back(i);
+
+		Buffer->push_back(NPBK_POSTAL2);
+		Buffer->push_back(0x00);
+		Buffer->push_back((TempBuffer.size()+6) / 256);
+		Buffer->push_back((TempBuffer.size()+6) % 256);
+		Buffer->push_back(++(*Number));
+		Buffer->push_back(0x00);
+		Buffer->append((const unsigned char*)TempBuffer.data(),TempBuffer.size());
+
+		Buffer->append((const unsigned char*)TempBuffer2.data(),TempBuffer2.size());
+	}
+
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
 GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PBKEntry *Entry)
 {
-	int		     	i, Pos = 1;
+	int		     	i, j, Pos = 1,Num;
 	GSM_PBK_SubEntryType    Type;
 	GSM_PBKSubEntry 	*SubEntry,*PrevSubEntry=NULL;
 	BOOLEAN			Found;
@@ -316,6 +523,11 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 				Type = PBK_Text_URL;
 				(*Debug)->Deb("      URL");
 			}
+		case NPBK_PUSHTOTALK_ID: //no break
+			if (Type == PBK_Not_Assigned) {
+				Type = PBK_Text_PTT;
+				(*Debug)->Deb("      Push To Talk");
+			}
 		case NPBK_USER_ID: // no break;
 			if (Type == PBK_Not_Assigned) {
 				Type = PBK_Text_UserID;
@@ -324,6 +536,52 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 			(*Debug)->Deb(" \"%s\"\n",UnicodeToStringReturn(NokiaGetUnicodeString(Buffer+Pos+6)));
 			Entry->AddText(Type, NokiaGetUnicodeString(Buffer+Pos+6));
 			break;
+		case NPBK_POSTAL2:
+			Num = Buffer[Pos+7];
+			for (j=0;j<Num;j++) {
+				Pos+=Buffer[Pos+2]*256+Buffer[Pos+3];
+				Type = PBK_Not_Assigned;
+				switch (Buffer[Pos]) {
+				case NPBK_POSTAL2_ADDRESS: //no break
+					if (Type == PBK_Not_Assigned) {
+						Type = PBK_Text_Postal;
+						(*Debug)->Deb("      Address");
+					}
+				case NPBK_POSTAL2_STREET: //no break
+					if (Type == PBK_Not_Assigned)  {
+						Type = PBK_Text_Postal_Street;
+						(*Debug)->Deb("      Street");
+					}
+				case NPBK_POSTAL2_CITY: //no break
+					if (Type == PBK_Not_Assigned) {
+						Type = PBK_Text_Postal_City;
+						(*Debug)->Deb("      City");
+					}
+				case NPBK_POSTAL2_STATE: //no break
+					if (Type == PBK_Not_Assigned)   {
+						Type = PBK_Text_Postal_State;
+						(*Debug)->Deb("      State");
+					}
+				case NPBK_POSTAL2_ZIPCODE: //no break
+					if (Type == PBK_Not_Assigned)  {
+						Type = PBK_Text_Postal_ZIP_Code;
+						(*Debug)->Deb("      ZIP code");
+					}
+				case NPBK_POSTAL2_COUNTRY: //no break
+					if (Type == PBK_Not_Assigned) {
+						Type = PBK_Text_Postal_Country;
+						(*Debug)->Deb("      Country");
+					}
+				default: //no break
+					if (Type == PBK_Not_Assigned) {
+						(*Debug)->Deb("      Unknown adress \"%s\"\n",UnicodeToStringReturn(NokiaGetUnicodeString(Buffer+Pos+10)));
+						return GSM_Return_Error(GSM_ERR_UNKNOWN);
+					}
+				}
+				(*Debug)->Deb(" \"%s\"\n",UnicodeToStringReturn(NokiaGetUnicodeString(Buffer+Pos+6)));
+				Entry->AddText(Type, NokiaGetUnicodeString(Buffer+Pos+6));
+			}
+			break;
 		case NPBK_DATETIME:
 			(*Debug)->Deb("      DateTime\n");
 			Entry->AddDateTime(PBK_DateTime_Call_Length, *NokiaGetDT(Buffer+Pos+6));
@@ -344,7 +602,6 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 				if (Found) break;
 			}
 			PrevSubEntry->Length = Buffer[Pos+9]*256*256+Buffer[Pos+10]*256+Buffer[Pos+11];
-//			if (PrevSubEntry->Length == 0) PrevSubEntry->Length=-1;
 			break;
 		//todo
 		case NPBK_SMSLIST_ID:
@@ -394,6 +651,32 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
+GSM_Error GSM_Phone_NDCT34::ReplyGetPBKFeatures(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	GSM_PBK_Features *Entry = (GSM_PBK_Features *)S;
+	int 		 i,pos=6;
+
+	Entry->Types.clear();
+	for (i=0;i<msg->Buffer.data()[5]-1;i++) {
+		Entry->Types.push_back(msg->Buffer.data()[pos+4]);
+		pos+=msg->Buffer.data()[pos+3];
+	}
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
+GSM_Error GSM_Phone_NDCT34::GetPBKFeatures(GSM_PBK_Features *Features)
+{
+	unsigned char Buff[] = {NOKIA_FRAME1, 0x25, 
+			        0x05, 	// memory type
+			        0x00};
+
+	Buff[4] = Get7110DCT4MemoryType(Features->Memory);
+	if (Buff[4] == 0x00) return GSM_Return_Error(GSM_ERR_UNKNOWN);
+
+	(*Debug)->Deb("SENT: getting phonebook features\n");
+	return (*Pho)->Write(Buff, sizeof(Buff), 0x03, 2, ID_GetPBK+ID, Features);
+}
+
 GSM_Error GSM_Phone_NDCT34::ReplySetPBK(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
 	if (msg->Buffer.data()[6] == 0x0F) {
@@ -410,7 +693,7 @@ GSM_Error GSM_Phone_NDCT34::ReplySetPBK(GSM_Protocol_Message *msg, DebugInfo **D
 			return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		case 0x3e:
 			(*Debug)->Deb(", too much subentries\n");
-			return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+			return GSM_Return_Error(GSM_ERR_TOO_MANY_ENTRIES);
 		default:
 			(*Debug)->Deb(", code %02X\n",msg->Buffer.data()[10]);
 			return GSM_Return_Error(GSM_ERR_UNKNOWN);
@@ -659,15 +942,14 @@ GSM_Error GSM_Phone_NDCT34::ReplyAddCalendar1(GSM_Protocol_Message *msg, DebugIn
 
 GSM_Error GSM_Phone_NDCT34::AddCalendar1(GSM_CalendarEntry *Entry)
 {
-	GSM_Error	       error;
-	time_t		  timet1, timet2;
-	unsignedstring	  Buffer;
+	GSM_Error	       	error;
+	time_t		  	timet1, timet2;
+	unsignedstring	  	Buffer;
 	GSM_CalendarSubEntry    *SubEntry, *Text = NULL, *Location = NULL;
 	GSM_CalendarSubEntry    *Phone = NULL, *DateStart = NULL, *Alarm = NULL;
- //     int		     RepeatEach = -1, RepeatDOW = -1, RepeatDay = -1, RepeatMonth = -1;
-	int     Loc;
-	unsigned char	   NoteType, NoteType2,Buff[2];
-	unsigned int	    diff;
+	int     		Loc;
+	unsigned char	   	NoteType, NoteType2,Buff[2];
+	unsigned int	    	diff;
 
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
