@@ -61,14 +61,20 @@ GSM_Error GSM_Backup::SavePbkToTextFile(FILE *file)
 			case PBK_Text_Phone_Home  : sprintf(buff2,"NumberHome"); 	break;
 			case PBK_Text_Phone_Work  : sprintf(buff2,"NumberWork"); 	break;
 			case PBK_Text_Phone_Fax   : sprintf(buff2,"NumberFax"); 	break;
+			case PBK_Text_Postal	  : sprintf(buff2,"Address"); 		break;
+			case PBK_Text_Postal_City : sprintf(buff2,"City"); 		break;
+			case PBK_Text_Postal_State: sprintf(buff2,"State"); 		break;
+			case PBK_Text_Postal_ZIP_Code: sprintf(buff2,"Zip"); 		break;
+			case PBK_Text_Postal_Country: sprintf(buff2,"Country"); 	break;
+			case PBK_Text_Postal_Street : sprintf(buff2,"Street"); 		break;
 			case PBK_Text_Email       : sprintf(buff2,"Email"); 		break;
 			case PBK_Text_URL         : sprintf(buff2,"URL"); 		break;
-			case PBK_Text_Postal	  : sprintf(buff2,"Postal"); 		break;
 			case PBK_Text_UserID	  : sprintf(buff2,"UserID"); 		break;
 			case PBK_Text_Note	  : sprintf(buff2,"Note"); 		break;
 			case PBK_Text_Name	  : sprintf(buff2,"Name"); 		break;
-			case PBK_Text_Name_Last	  : sprintf(buff2,"FirstName"); 	break;
-			case PBK_Text_Name_First  : sprintf(buff2,"LastName"); 		break;
+			case PBK_Text_Name_Last	  : sprintf(buff2,"LastName"); 		break;
+			case PBK_Text_Name_First  : sprintf(buff2,"FirstName"); 	break;
+			case PBK_Text_PTT         : sprintf(buff2,"PTT"); 		break;
 			default			  : break;
 			}
 			if (buff2[0] == 0) continue;
@@ -297,7 +303,7 @@ GSM_Error GSM_Backup::SaveToTextFile(char *FileName)
 	SaveTextFilePart(StringToUnicodeReturn(""), file, TRUE);
 
 	SaveTextFilePart(StringToUnicodeReturn("[Backup]"), file, TRUE);
-	SaveTextFilePart(StringToUnicodeReturn("Format=1.04"), file, TRUE);
+	SaveTextFilePart(StringToUnicodeReturn("Format=1.05"), file, TRUE);
 
 	sprintf(buff,"IMEI = \"%s\"",IMEI);
 	SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
@@ -339,6 +345,7 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 	GSM_PBKSubEntry 	*SubEntry;
 	int			i;
 	BOOLEAN			Found;
+	wchart			Txt;
 
 	StringToUnicode("PhonePBK",x);
 	Section = NULL;
@@ -364,11 +371,17 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 			if (!wcscmp(value,StringToUnicodeReturn("NumberWork"))) 	PBKType = PBK_Text_Phone_Work;
 			if (!wcscmp(value,StringToUnicodeReturn("NumberFax"))) 		PBKType = PBK_Text_Phone_Fax;
 			if (!wcscmp(value,StringToUnicodeReturn("NumberGeneral"))) 	PBKType = PBK_Text_Phone_General;
-			if (!wcscmp(value,StringToUnicodeReturn("Postal"))) 		PBKType = PBK_Text_Postal;
-			if (!wcscmp(value,StringToUnicodeReturn("Note"))) 		PBKType = PBK_Text_Note;
+			if (!wcscmp(value,StringToUnicodeReturn("Address"))) 		PBKType = PBK_Text_Postal;
+			if (!wcscmp(value,StringToUnicodeReturn("City"))) 		PBKType = PBK_Text_Postal_City;
+			if (!wcscmp(value,StringToUnicodeReturn("State"))) 		PBKType = PBK_Text_Postal_State;
+			if (!wcscmp(value,StringToUnicodeReturn("Zip"))) 		PBKType = PBK_Text_Postal_ZIP_Code;
+			if (!wcscmp(value,StringToUnicodeReturn("Country"))) 		PBKType = PBK_Text_Postal_Country;
+			if (!wcscmp(value,StringToUnicodeReturn("Street"))) 		PBKType = PBK_Text_Postal_Street;
 			if (!wcscmp(value,StringToUnicodeReturn("Email"))) 		PBKType = PBK_Text_Email;
 			if (!wcscmp(value,StringToUnicodeReturn("URL"))) 		PBKType = PBK_Text_URL;
 			if (!wcscmp(value,StringToUnicodeReturn("UserID"))) 		PBKType = PBK_Text_UserID;
+			if (!wcscmp(value,StringToUnicodeReturn("Note"))) 		PBKType = PBK_Text_Note;
+			if (!wcscmp(value,StringToUnicodeReturn("PTT"))) 		PBKType = PBK_Text_PTT;
 			if (PBKType == PBK_Not_Assigned) continue;
 
 			sprintf(x2,"Entry%02iText",i);
@@ -377,7 +390,8 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 			if (UnicodeLength(value)==0) continue;
 
 			value[UnicodeLength(value)-1] = 0;
-			PBKEntry->AddText(PBKType,value+1);
+			ReadTextFilePart(value+1, &Txt);
+			PBKEntry->AddText(PBKType,(wchar_t *)Txt.data());
 		}
 		Found = FALSE;
 		SubEntry = NULL;
