@@ -331,6 +331,7 @@ GSM_Backup::GSM_Backup()
 	Cal = NULL;
 	SMS = NULL;
 	MMS = NULL;
+	JAD = NULL;
 	ToDo = NULL;
 	Notes = NULL;
 
@@ -358,6 +359,12 @@ void GSM_Backup::Delete_MMS()
 	MMS = NULL;
 }
 
+void GSM_Backup::Delete_JAD()
+{
+	delete(JAD);
+	JAD = NULL;
+}
+
 void GSM_Backup::Delete_Calendar()
 {
 	delete(Cal);
@@ -382,6 +389,7 @@ GSM_Backup::~GSM_Backup()
 	Delete_Calendar();
 	Delete_SMS();
 	Delete_MMS();
+	Delete_JAD();
 	Delete_Notes();
 	Delete_ToDo();
 }
@@ -418,6 +426,17 @@ BOOLEAN GSM_Backup::GetNext_MMS(GSM_Backup_MMSEntry **En)
 	return TRUE;
 }
 
+BOOLEAN GSM_Backup::GetNext_JAD(GSM_Backup_JADEntry **En)
+{
+	if ((*En) == NULL) {
+		(*En) = JAD;
+	} else {
+		(*En) = (*En)->GetNext();
+	}
+	if ((*En) == NULL) return FALSE;
+	return TRUE;
+}
+
 BOOLEAN GSM_Backup::GetNext_Cal(GSM_Backup_CalEntry **En)
 {
 	if ((*En) == NULL) {
@@ -542,6 +561,22 @@ void GSM_Backup::Add_MMS(GSM_MMSFile *En)
 	}
 }
 
+void GSM_Backup::Add_JAD(GSM_File *En)
+{
+	GSM_Backup_JADEntry *Entry,*Entry2;
+
+	Entry = new GSM_Backup_JADEntry;
+	Entry->SetEntry(En);
+
+	if (JAD == NULL) {
+		JAD = Entry;
+	} else {
+		Entry2 = JAD;
+		while (Entry2->GetNext()!=NULL) Entry2 = Entry2->GetNext();
+		Entry2->SetNext(Entry);
+	}
+}
+
 void GSM_Backup::Add_SMS(GSM_SMSList *En)
 {
 	Add_SMS0(&SMS,En);
@@ -701,6 +736,40 @@ void GSM_Backup_MMSEntry::SetEntry(GSM_MMSFile *En)
 
 /* ------------------------------------------------------------------------- */
 
+GSM_Backup_JADEntry::GSM_Backup_JADEntry()
+{
+	Next = NULL;
+	Entry = NULL;
+}
+
+GSM_Backup_JADEntry::~GSM_Backup_JADEntry()
+{
+	delete(Next);
+	delete(Entry);
+}
+
+void GSM_Backup_JADEntry::SetNext(GSM_Backup_JADEntry *Nxt)
+{
+	Next = Nxt;
+}
+
+GSM_Backup_JADEntry *GSM_Backup_JADEntry::GetNext()
+{
+	return Next;
+}
+
+GSM_File *GSM_Backup_JADEntry::GetEntry()
+{
+	return Entry;
+}
+
+void GSM_Backup_JADEntry::SetEntry(GSM_File *En)
+{
+	Entry = En;
+}
+
+/* ------------------------------------------------------------------------- */
+
 GSM_Backup_NoteEntry::GSM_Backup_NoteEntry()
 {
 	Next = NULL;
