@@ -91,6 +91,22 @@ private:
         GSM_MMSFile             *Entry;
 };
 
+class GSM_Backup_JADEntry {
+        friend class GSM_Backup;
+public:
+        GSM_Backup_JADEntry();
+        ~GSM_Backup_JADEntry();
+
+        GSM_Backup_JADEntry     *GetNext();
+	GSM_File		*GetEntry();
+private:
+        void                    SetNext(GSM_Backup_JADEntry *Nxt);
+        void                    SetEntry(GSM_File *En);
+
+        GSM_Backup_JADEntry     *Next;
+        GSM_File                *Entry;
+};
+
 class GSM_Backup_NoteEntry {
         friend class GSM_Backup;
 public:
@@ -143,6 +159,7 @@ public:
 	void			GetFileFunctions(GSM_Backup_FileFormatNum Num, GSM_Backup_FileFormatFunctions *Func);
         GSM_Error               ReadFromFile(char *FileName);
 	GSM_Error 		SaveToFile(char *FileName);
+        BOOLEAN                 GetNext_JAD(GSM_Backup_JADEntry **En);
         BOOLEAN                 GetNext_MMS(GSM_Backup_MMSEntry **En);
         BOOLEAN                 GetNext_SMS(GSM_Backup_SMSEntry **En);
         BOOLEAN                 GetNext_PBK(GSM_Backup_PBKEntry **En);
@@ -153,6 +170,7 @@ public:
         void                    Add_Cal(GSM_CalendarEntry *En);
         void                    Add_SMS(GSM_SMSList *En);
         void                    Add_MMS(GSM_MMSFile *En);
+        void                    Add_JAD(GSM_File *En);
         void                    Add_Note(GSM_NoteEntry *En);
         void                    Add_ToDo(GSM_ToDoEntry *En);
         void                    LinkSMS();
@@ -161,12 +179,14 @@ public:
         void                    Delete_SMS();
         void                    Delete_Calendar();
         void                    Delete_MMS();
+        void                    Delete_JAD();
         void                    Delete_Notes();
         void                    Delete_ToDo();
 private:
         GSM_Backup_PBKEntry     *PBK;
         GSM_Backup_CalEntry     *Cal;
         GSM_Backup_SMSEntry     *SMS;
+        GSM_Backup_JADEntry     *JAD;
         GSM_Backup_MMSEntry     *MMS;
 	GSM_Backup_NoteEntry    *Notes;
 	GSM_Backup_ToDoEntry    *ToDo;
