@@ -29,6 +29,9 @@ char *GSM_GetErrorInfo(GSM_Error e)
 		{GSM_ERR_TIMEOUT,			"No response in specified time."},
 		{GSM_ERR_EMPTY,				"Empty"},
 		{GSM_ERR_NOT_SUPPORTED,			"Not supported by phone"},
+		{GSM_ERR_CONVERTED,			"Converted to phone format"},
+		{GSM_ERR_TOO_MANY_ENTRIES,		"Entry cut off"},
+		{GSM_ERR_INVALID_LOCATION,		"Invalid location"},
 		{GSM_ERR_INSIDE_PHONE_MENU,		"Data are edited in phone menu. Leave it before editing from PC."},
 		{GSM_ERR_NO_SIM,			"Function requires SIM card"},
 		{GSM_ERR_GPLUS_NOT_SUPPORTED,		"Not supported by Gammu+"},
@@ -312,9 +315,16 @@ GSM_Error GSM_EncodeSMSText(unsigned char *Destination, const wchar_t *Source, i
 	BOOLEAN 	found;
 	wchar_t 	srcchar;
 
-	(*len) 			= 0;
+	(*len) 		= 0;
 	Destination[l] 	= 0;
-	destbit			= 1; //fixme
+	destbit		= 1;
+	for (j=1;j<udhlen*7;j++) {
+		if (destbit==128) {
+			destbit = 1;
+			continue;
+		}
+		destbit*=2;
+	}
 	while (Source[pos] != 0) {
 		found 		= FALSE;
 		gsmcharlen 	= 1;
