@@ -345,22 +345,28 @@ GSM_Error GSM_SMSEntry::GetDecodedText(wchar_t *text)
 
 GSM_Error GSM_SMSEntry::SetDecodedText(wchar_t *Text)
 {
-	unsignedstring  TMP;
-	unsigned char	Buffer[140];
+	unsignedstring  TMP,TMP2;
+	unsigned char	Buffer[200];
 	int		i,j;
 	GSM_Error	error;
 
+	error = GetUDH(&TMP2);
+	if (error.Code != GSM_ERR_NONE) return error;
+
 	switch (GetCoding()) {
 	case SMS_Coding_Unicode_No_Compression:
+		//fixme
 		for (i=0;i<UnicodeLength(Text);i++) {
 			TMP.push_back(Text[i]/256);
 			TMP.push_back(Text[i]%256);
 		}
 		return SetText(&TMP);
 	case SMS_Coding_Default_No_Compression:
-		error = GSM_EncodeSMSText(Buffer, Text, &j, 160, 0);
+//		error = GSM_EncodeSMSText(Buffer, Text, &j, 133-TMP2.size(), TMP2.size());
+		error = GSM_EncodeSMSText(Buffer, Text, &j, 140-TMP2.size(), TMP2.size());
 		if (error.Code != GSM_ERR_NONE) return error;
-		for (i=0;i<j;i++) TMP.push_back(Buffer[i]);
+		for (i=0;i<(j*7/8);i++) TMP.push_back(Buffer[i]);
+printf("%i\n",(j*7/8));
 		return SetText(&TMP);		
 	case SMS_Coding_Unicode_Compression:
 	case SMS_Coding_Default_Compression:
