@@ -540,6 +540,21 @@ void GetMemory(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[]
 			case PBK_Text_Postal:
 				printf("Postal address \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
 				break;
+			case PBK_Text_Postal_Street:
+				printf("Street \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Postal_City:
+				printf("City \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Postal_State:
+				printf("State \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Postal_ZIP_Code:
+				printf("ZIP \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
+			case PBK_Text_Postal_Country:
+				printf("Country \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
+				break;
 			case PBK_Text_UserID:
 				printf("User ID \"%s\"",UnicodeToStringReturn(SubEntry->GetText()));
 				break;
