@@ -25,10 +25,10 @@ BEGIN_EVENT_TABLE(CfgDlg,wxDialog)
 	////Manual Code End
 	
 	EVT_CLOSE(CfgDlg::OnClose)
-	EVT_COMBOBOX(ID_WXCOMBOBOX2,CfgDlg::WxComboBox2Selected)
 	EVT_COMBOBOX(ID_WXCOMBOBOX1,CfgDlg::WxComboBox1Selected)
-	EVT_BUTTON(ID_WXBUTTON3,CfgDlg::WxButton3Click)
+	EVT_COMBOBOX(ID_WXCOMBOBOX2,CfgDlg::WxComboBox2Selected)
 	EVT_BUTTON(ID_WXBUTTON2,CfgDlg::WxButton2Click)
+	EVT_BUTTON(ID_WXBUTTON3,CfgDlg::WxButton3Click)
 END_EVENT_TABLE()
 ////Event Table End
 
@@ -52,22 +52,26 @@ void CfgDlg::CreateGUIControls()
 
 	SetTitle(wxT("Configuration for phone connection"));
 	SetIcon(wxNullIcon);
-	SetSize(8,8,409,182);
+	SetSize(8,8,409,207);
 	Center();
 	
 
-	WxCheckBox1 = new wxCheckBox(this, ID_WXCHECKBOX1, wxT("set phone clock from your computer"), wxPoint(14,103), wxSize(296,18), 0, wxDefaultValidator, wxT("WxCheckBox1"));
-	WxCheckBox1->Show(false);
-
-	wxArrayString arrayStringFor_WxComboBox2;
-	WxComboBox2 = new wxComboBox(this, ID_WXCOMBOBOX2, wxT("WxComboBox2"), wxPoint(92,76), wxSize(218,21), arrayStringFor_WxComboBox2, wxCB_DROPDOWN | wxCB_READONLY | wxCB_SORT, wxDefaultValidator, wxT("WxComboBox2"));
+	WxCheckBox2 = new wxCheckBox(this, ID_WXCHECKBOX2, wxT("log communication for debug"), wxPoint(14,122), wxSize(240,18), 0, wxDefaultValidator, wxT("WxCheckBox2"));
 
 	wxArrayString arrayStringFor_WxComboBox1;
 	WxComboBox1 = new wxComboBox(this, ID_WXCOMBOBOX1, wxT("WxComboBox1"), wxPoint(93,22), wxSize(298,21), arrayStringFor_WxComboBox1, wxCB_DROPDOWN | wxCB_READONLY | wxCB_SORT, wxDefaultValidator, wxT("WxComboBox1"));
 
-	WxButton3 = new wxButton(this, ID_WXBUTTON3, wxT("&Cancel"), wxPoint(280,128), wxSize(81,23), 0, wxDefaultValidator, wxT("WxButton3"));
+	WxEdit1 = new wxTextCtrl(this, ID_WXEDIT1, wxT("WxEdit1"), wxPoint(93,49), wxSize(216,21), 0, wxDefaultValidator, wxT("WxEdit1"));
 
-	WxButton2 = new wxButton(this, ID_WXBUTTON2, wxT("&OK"), wxPoint(40,127), wxSize(82,23), 0, wxDefaultValidator, wxT("WxButton2"));
+	wxArrayString arrayStringFor_WxComboBox2;
+	WxComboBox2 = new wxComboBox(this, ID_WXCOMBOBOX2, wxT("WxComboBox2"), wxPoint(92,76), wxSize(218,21), arrayStringFor_WxComboBox2, wxCB_DROPDOWN | wxCB_READONLY | wxCB_SORT, wxDefaultValidator, wxT("WxComboBox2"));
+
+	WxCheckBox1 = new wxCheckBox(this, ID_WXCHECKBOX1, wxT("set phone clock from your computer"), wxPoint(14,103), wxSize(296,18), 0, wxDefaultValidator, wxT("WxCheckBox1"));
+	WxCheckBox1->Show(false);
+
+	WxButton2 = new wxButton(this, ID_WXBUTTON2, wxT("&OK"), wxPoint(40,151), wxSize(82,23), 0, wxDefaultValidator, wxT("WxButton2"));
+
+	WxButton3 = new wxButton(this, ID_WXBUTTON3, wxT("&Cancel"), wxPoint(280,152), wxSize(81,23), 0, wxDefaultValidator, wxT("WxButton3"));
 
 	WxStaticText3 = new wxStaticText(this, ID_WXSTATICTEXT3, wxT("Phone model"), wxPoint(14,78), wxDefaultSize, 0, wxT("WxStaticText3"));
 
@@ -75,9 +79,7 @@ void CfgDlg::CreateGUIControls()
 
 	WxStaticText1 = new wxStaticText(this, ID_WXSTATICTEXT1, wxT("Type"), wxPoint(15,23), wxDefaultSize, 0, wxT("WxStaticText1"));
 
-	WxEdit1 = new wxTextCtrl(this, ID_WXEDIT1, wxT("WxEdit1"), wxPoint(93,49), wxSize(216,21), 0, wxDefaultValidator, wxT("WxEdit1"));
-
-	WxStaticBox1 = new wxStaticBox(this, ID_WXSTATICBOX1, wxT("Parameters"), wxPoint(3,6), wxSize(395,119));
+	WxStaticBox1 = new wxStaticBox(this, ID_WXSTATICBOX1, wxT("Parameters"), wxPoint(3,6), wxSize(395,139));
 	////GUI Items Creation End
 }
 
@@ -86,7 +88,7 @@ void CfgDlg::OnClose(wxCloseEvent& /*event*/)
 	Destroy();
 }
 
-void CfgDlg::SetConfig(char *Conn, char *Dev, char *Mod, GSM_StateMachine *s2)
+void CfgDlg::SetConfig(GSM_GPlusConfig *CFG2, GSM_StateMachine *s2)
 {
 	list<GSM_Protocol_Info>::iterator 	proinfo;
 	list<GSM_Phone_Info>::iterator 		phoinfo;
@@ -96,12 +98,13 @@ void CfgDlg::SetConfig(char *Conn, char *Dev, char *Mod, GSM_StateMachine *s2)
     char                                buff[200];
     
     s=s2;
-    Connection = Conn;
-    Device = Dev;
-    Model = Mod;
+    CFG = CFG2;
     
+    if (strcmp(CFG->LogLevel,"nothing")) WxCheckBox2->SetValue(true);
+    if (!strcmp(CFG->SyncTime,"yes")) WxCheckBox1->SetValue(true);
+        
     //device
-    WxEdit1->SetValue(StringToUnicodeReturn(Device));
+    WxEdit1->SetValue(StringToUnicodeReturn(CFG->Device));
     
     //phone model
     WxComboBox2->Clear();
@@ -116,7 +119,7 @@ void CfgDlg::SetConfig(char *Conn, char *Dev, char *Mod, GSM_StateMachine *s2)
             sprintf(buff,"%s (%s)",(*phoinfo).Model,(*phoinfo).CodeNameModel);
             WxComboBox2->Append(buff);
             Num++;
-            if (!strcmp(Model,(*phoinfo).Model)) WxComboBox2->SetSelection(Num);            
+            if (!strcmp(CFG->Phone,(*phoinfo).Model)) WxComboBox2->SetSelection(Num);            
         }
     }    
     
@@ -124,13 +127,6 @@ void CfgDlg::SetConfig(char *Conn, char *Dev, char *Mod, GSM_StateMachine *s2)
     SelectChoice2();
 }
 
-void CfgDlg::GetConfig(char *Conn, char *Dev, char *Mod)
-{
-    sprintf(Conn,"%s",Connection);
-    sprintf(Dev,"%s",Device);
-    sprintf(Mod,"%s",Model);
-}
-
 typedef struct {
  	char		*Connection;
 	char		*Description;
@@ -164,7 +160,7 @@ void CfgDlg::SelectChoice1()
             if (!s->Protocols->GetNext(&pro)) break;
             for (proinfo=pro->Info.begin(); proinfo!=pro->Info.end(); ++proinfo) {
                 if (!strcmp((*proinfo).Protocol,X2[i].Connection)) {
-                    sprintf(Connection,"%s",X2[i].Connection);
+                    sprintf(CFG->Protocol,"%s",X2[i].Connection);
                     WxEdit1->Enable((*proinfo).NeedPort);
                     WxStaticText2->Enable((*proinfo).NeedPort);
                 }
@@ -185,7 +181,7 @@ void CfgDlg::SelectChoice2()
 
     WxComboBox1->Clear();
     if (WxComboBox2->GetValue()=="(selected automatic)") {
-        sprintf(Model,"");
+        sprintf(CFG->Phone,"");
         pro = NULL;
         while(1) {
             if (!s->Protocols->GetNext(&pro)) break;
@@ -207,7 +203,7 @@ void CfgDlg::SelectChoice2()
                 if ((*phoinfo).Model[0]==0) continue;
                 sprintf(buff,"%s (%s)",(*phoinfo).Model,(*phoinfo).CodeNameModel);
                 if (strcmp(buff,WxComboBox2->GetStringSelection())) continue;
-                sprintf(Model,"%s",(*phoinfo).Model);
+                sprintf(CFG->Phone,"%s",(*phoinfo).Model);
 
                 pro = NULL;
                 while(1) {
@@ -232,7 +228,7 @@ void CfgDlg::SelectChoice2()
         j = 0;
         while (X2[j].Connection[0] != 0) {
             if (!strcmp(WxComboBox1->GetString(i),X2[j].Description)) {
-                if (!strcmp(Connection,X2[j].Connection)) {
+                if (!strcmp(CFG->Protocol,X2[j].Connection)) {
                     WxComboBox1->SetSelection(i);
                 }                
             }
@@ -248,7 +244,20 @@ void CfgDlg::SelectChoice2()
  */
 void CfgDlg::WxButton2Click(wxCommandEvent& event)
 {
-    sprintf(Device,"%s",UnicodeToStringReturn((wchar_t *)((const wchar_t *)WxEdit1->GetValue().wc_str(wxConvLibc))));
+    sprintf(CFG->Device,"%s",UnicodeToStringReturn((wchar_t *)((const wchar_t *)WxEdit1->GetValue().wc_str(wxConvLibc))));
+
+    if (WxCheckBox1->GetValue()) {
+        sprintf(CFG->SyncTime,"yes");
+    } else {
+        sprintf(CFG->SyncTime,"no");
+    }
+    
+    if (WxCheckBox2->GetValue()) {
+        sprintf(CFG->LogLevel,"textall");
+        sprintf(CFG->LogFile,"log");
+    } else {
+        sprintf(CFG->LogLevel,"nothing");
+    }
     
 //    wxMessageBox(Connection,"connection",
 //           wxICON_WARNING | wxOK);
