@@ -115,11 +115,6 @@ void MainFrm::Mnunewphone1003Click(wxCommandEvent& event)
     unsigned char       Model[50];
     unsigned char       Firm[50];
     unsigned char       Man[50];
-	char 		        Device[200], Protocol[200], Phone[200],Comp[200];;
-	wchar_t		        *value, x[200];
-#ifndef WIN32
-	char		        tmp[500];
-#endif
     GSM_GPlusConfig     CFG;
 
     dialog = new CfgDlg(this,-1,"About...",wxDefaultPosition,wxDefaultSize,CfgDlg_STYLE);
@@ -127,7 +122,7 @@ void MainFrm::Mnunewphone1003Click(wxCommandEvent& event)
     s = new GSM_StateMachine(NULL,"",false);
     s->ReadCfg(&CFG);
     
-    dialog->SetConfig(CFG.Protocol, CFG.Device, CFG.Phone,s);
+    dialog->SetConfig(&CFG,s);
 
     while (true) {
         if (dialog->ShowModal()!= wxID_OK) {
@@ -137,8 +132,14 @@ void MainFrm::Mnunewphone1003Click(wxCommandEvent& event)
         
         s->SaveCfg(&CFG);
         
-        dialog->GetConfig(CFG.Protocol, CFG.Device, CFG.Phone);
-                              
+        delete (s);
+        if (!strcmp(CFG.LogLevel,"nothing")) {
+            s = new GSM_StateMachine(NULL,"",false);
+        } else {
+            s = new GSM_StateMachine(NULL,CFG.LogFile,true);
+        }
+        s->ReadCfg(&CFG);
+        
         error = s->Open(&CFG);
         if (error.Code == GSM_ERR_NONE) break;
         PrintError (error);
@@ -155,6 +156,9 @@ void MainFrm::Mnunewphone1003Click(wxCommandEvent& event)
 	error = s->Phones->Current->GetFirmwareVersion(Firm);
 	PrintError(error);
 
+    if (!strcmp(CFG.SyncTime,"yes")) {
+    }
+
     sprintf(buff, "Phone %s %s %s",Man,Model,Firm);
 
     Backup = new GSM_Backup;
