@@ -67,8 +67,8 @@ class PhoneFrm : public wxMDIChildFrame
                 //GUI Control Declaration Start and GUI Control Declaration End.
 		//wxDev-C++ will remove them. Add custom code after the block.
 		////GUI Control Declaration Start
-		wxMenu *MMSSingleUpWxPopupMenu;
 		wxMenu *SMSSingleUpWxPopupMenu;
+		wxMenu *MMSSingleUpWxPopupMenu;
 		wxListCtrl *JavaDownWxListCtrl;
 		wxGridSizer *WxGridSizer16;
 		wxPanel *WxPanel27;
@@ -77,6 +77,8 @@ class PhoneFrm : public wxMDIChildFrame
 		wxPanel *WxPanel26;
 		wxSplitterWindow *WxSplitterWindow8;
 		wxBoxSizer *WxBoxSizer19;
+		wxButton *AppAddWxButton;
+		wxButton *GameAddWxButton;
 		wxButton *JavaGetWxButton;
 		wxPanel *WxPanel25;
 		wxBoxSizer *WxBoxSizer18;
@@ -216,16 +218,18 @@ class PhoneFrm : public wxMDIChildFrame
 		enum
 		{
 			////GUI Enum Control ID Start
-			ID_MNU_SAVETOFILE_1104 = 1104,
-			
 			ID_MNU_FORWARD_1095 = 1095,
 			ID_MNU_SENDNEWSMSTOSMSNUMBERS_1144 = 1144,
 			
+			ID_MNU_SAVETOFILE_1104 = 1104,
+			
 			ID_JAVADOWNWXLISTCTRL = 1214,
 			ID_WXPANEL27 = 1211,
 			ID_JAVAUPWXLISTCTRL = 1210,
 			ID_WXPANEL26 = 1208,
 			ID_WXSPLITTERWINDOW8 = 1207,
+			ID_APPADDWXBUTTON = 1218,
+			ID_GAMEADDWXBUTTON = 1217,
 			ID_JAVAGETWXBUTTON = 1215,
 			ID_WXPANEL25 = 1205,
 			ID_JAVAWXNOTEBOOKPAGE = 1203,
@@ -344,7 +348,7 @@ class PhoneFrm : public wxMDIChildFrame
 		void MMSUpWxListCtrlItemActivated(wxListEvent& event);
 		void PBKUpWxListCtrlSelected(wxListEvent& event);
 		void SMSSendWxButtonClick(wxCommandEvent& event);
-	void Mnuforward1095Click(wxCommandEvent& event);
+	    void Mnuforward1095Click(wxCommandEvent& event);
 		void SMSUpWxListCtrlRightClick(wxListEvent& event);
 		void SMSSearchWxButtonClick(wxCommandEvent& event);
 		void WxNoteBookPage3UpdateUI(wxUpdateUIEvent& event);
@@ -352,7 +356,7 @@ class PhoneFrm : public wxMDIChildFrame
 		void MMSFileWxMediaCtrlMediaLoaded(wxMediaEvent& event);
 		void MMSSaveWxButtonClick(wxCommandEvent& event);
 		void MMSUpWxListCtrlSelected(wxListEvent& event);
-	void Mnusavetofile1104Click(wxCommandEvent& event);
+	    void Mnusavetofile1104Click(wxCommandEvent& event);
 		void MMSUpWxListCtrlRightClick(wxListEvent& event);
 		void CalendarGetWxButtonClick(wxCommandEvent& event);
 		void WxCalendarCtrl1SelChanged(wxCalendarEvent& event);
@@ -360,13 +364,13 @@ class PhoneFrm : public wxMDIChildFrame
 		void CalendarUPWxListCtrlSelected(wxListEvent& event);
 
     public:
-        GSM_Backup                          *Backup;
+        GSM_Backup *Backup;
 		void PbkSearchWxButtonClick(wxCommandEvent& event);
 		void WxButton1Click(wxCommandEvent& event);
-	void Mnusendnewsmstosmsnumbers1144Click(wxCommandEvent& event);
+    	void Mnusendnewsmstosmsnumbers1144Click(wxCommandEvent& event);
 		void MMSSearchWxButtonClick(wxCommandEvent& event);
 		void CalendarSearchWxButtonClick(wxCommandEvent& event);
-	void Mnuuploadfile1145Click(wxCommandEvent& event);
+    	void Mnuuploadfile1145Click(wxCommandEvent& event);
 		void BackupWxButtonClick(wxCommandEvent& event);
 		void RestoreWxButtonClick(wxCommandEvent& event);
 		void AddFileWxButtonClick(wxCommandEvent& event);
@@ -377,6 +381,11 @@ class PhoneFrm : public wxMDIChildFrame
 		void JavaWxButtonClick(wxCommandEvent& event);
 		void OnlineInfoWxButtonClick(wxCommandEvent& event);
 		void JavaGetWxButtonClick(wxCommandEvent& event);
+		void JavaUpWxListCtrlSelected(wxListEvent& event);
+		void JavaAddWxButtonClick(wxCommandEvent& event);
+		void GameAddWxButtonClick(wxCommandEvent& event);
+		void AppAddWxButtonClick(wxCommandEvent& event);
+	void Mnusendnewsmstosmsnumbers1144Click1(wxCommandEvent& event);
         
 	private:
         BOOLEAN                             Phone;
@@ -389,7 +398,6 @@ class PhoneFrm : public wxMDIChildFrame
         int                                 ParentFolderIDNum;
         wchart                              CurrentFolderName, CurrentFolderName0;
         int                                 FileSystemNum;
-//        GSM_FileFolderInfoLists             Folders;
         GSM_FileFolderInfoListsSubEntry     *En2;
         
         //pbk
@@ -417,13 +425,19 @@ class PhoneFrm : public wxMDIChildFrame
         void FindFeatures(GSM_Backup_FileFormatFunctions *Func);		
 		
 		BOOLEAN EnterFolder();
+        GSM_FileFolderInfoListsSubEntry *GetFolderContent(const wchar_t *FileFolderID1);		
 		void DisplayFolder();
+        BOOLEAN FindJADFiles(long *Num, FileFolderInfo *FInfo, BOOLEAN DetailsAvail, unsignedstring Name, BOOLEAN Game);
+        BOOLEAN ReadOneFile(GSM_File *File);
+        bool UploadFile(GSM_File *File);
+        void AddJava(BOOLEAN Game);
 		
         BOOLEAN GetPbkMemories();
         void DisplayPBK(GSM_MemoryType Mem, long *PbkNum,long *ReceivedSec,long *DialledSec);
         void ReadPBKMemory(GSM_MemoryType Mem); 
         void FindNumber(wchar_t *Number);
-        bool RestorePBK(GSM_MemoryType Mem, wxString Text);        
+        bool RestorePBK(GSM_MemoryType Mem, wxString Text, wxListCtrl *List, int *Num);        
+        void DecodePBKSubEntry(GSM_PBKSubEntry *SubEntry, char *type, wchar_t *Value, BOOLEAN *FirstNum);        
         
         BOOLEAN ReadSMSMMSFolder(int Num2, GSM_SMSMMSFoldersSubEntry *SubFolder);
         BOOLEAN ReadSMSMMSFolders(BOOLEAN SMS);       
@@ -431,6 +445,7 @@ class PhoneFrm : public wxMDIChildFrame
         void ClearSMSView();    
         void ClearMMSView();
         void FindMMSFile(GSM_Backup_MMSEntry **En);  
+        void SendSMS(GSM_SMSList *List, wxListCtrl *ListCtrl);        
         
         void DisplayCalendar();
         BOOLEAN CheckCalendar();        
@@ -443,7 +458,7 @@ class PhoneFrm : public wxMDIChildFrame
         void ReadNotes();
                 
         void RestoreToDo();
-        void PhoneFrm::DisplayToDo();
+        void DisplayToDo();
         BOOLEAN CheckToDo();        
         void ReadToDo();
 };
